#!perl
package Test;
use File::Temp;

# our $login='admin';
# our $pass='adminpass';
# our $url='http://localhost/sugarcrm/service/v4/rest.php';
# our $testcampaign='Demo Campaign';
# our $testprospectlist='Demo users';
# our $testemailmarketing='Demo User send password';
# # These are needed only to send emails in campaigns
# our $testdsn='DBI:mysql:database=theqvdsugarcrm;host=db.prepro.qindel.com';
# our $testdbuser='sugarcrm';
# our $testdbpass='pass';
# our $testemail1='myemail1@mydomain.org';
# our $testemail2='myemail2@mydomain.org';
